@@ -119,13 +119,19 @@ signals:
     void matchRegExpToggled(bool);
     /** Emitted when the close button is clicked */
     void closeClicked();
+    /** Emitted when the return button is pressed in the search box */
+    void searchReturnPressed(const QString& text);
+    /** Emitted when shift+return buttons are pressed in the search box */
+    void searchShiftPlusReturnPressed();
 
 protected:
     virtual bool eventFilter(QObject* watched , QEvent* event);
 
+public slots:
+    void clearLineEdit();
+
 private slots:
     void notifySearchChanged();
-    void clearLineEdit();
 
 private:
     bool _foundMatch;
