@@ -58,6 +58,18 @@
 
 using namespace Konsole;
 
+/* Normally it would be enough to just have this determined via the window
+   manager. But there exist GPU drivers (NVIDIA) that have serious performance
+   issues if transparency is enbled inside Konsole. The rest of the system
+   works fine. NVIDIA users might want to use --notransparency to work 
+   around such issues. */
+static bool useTransparency()
+{
+    const KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
+    const bool compositingAvailable = KWindowSystem::compositingActive();
+    return compositingAvailable && args->isSet("transparency");
+}
+
 MainWindow::MainWindow()
     : KXmlGuiWindow()
     , _bookmarkHandler(0)
@@ -65,10 +77,12 @@ MainWindow::MainWindow()
     , _menuBarInitialVisibility(true)
     , _menuBarInitialVisibilityApplied(false)
 {
-    // It is userful to have translucent terminal area
-    setAttribute(Qt::WA_TranslucentBackground, true);
-    // But it is mostly annoying to have translucent menubar and tabbar
-    setAttribute(Qt::WA_NoSystemBackground, false);
+    if (useTransparency()) {
+        // It is userful to have translucent terminal area
+        setAttribute(Qt::WA_TranslucentBackground, true);
+        // But it is mostly annoying to have translucent menubar and tabbar
+        setAttribute(Qt::WA_NoSystemBackground, false);
+    }
 
     // create actions for menus
     setupActions();
